.. _dipy_developers:

Developers
==========


The core development team consists of the following individuals:

- **Eleftherios Garyfallidis**, University of Cambridge, UK (Now in Sherbrooke, CA)
- **Bago Amirbekian**, University of California, San Francisco, CA, US
- **Ariel Rokem**, Stanford University, CA, US
- **Stefan Van der Walt**, Stellenbosch University, ZA
- **Matthew Brett**, University of California, Berkeley, CA, US
- **Ian Nimmo-Smith**, MRC Cognition and Brain Sciences Unit, Cambridge, UK
- **Maxime Descoteaux**, University of Sherbrooke, QC, CA

And here is the rest of the wonderful contributors:

- **Mauro Zucchelli**, University of Verona, IT
- **Matthieu Dumont**, PAVI, Sherbrooke, QC, CA
- **Samuel St-Jean**, University of Sherbrooke, QC, CA
- **Gabriel Girard**, University of Sherbrooke, QC, CA
- **Michael Paquette**, University of Sherbrooke, QC, CA
- **Christopher Nguyen**, University of California, Los Angeles, CA, US
- **Emanuele Olivetti**, NeuroInformatics Laboratory (NILab), Trento, IT
- **Yaroslav Halchenco**, PBS Department, Dartmouth, NH, US
- **Emmanuel Caruyer**, University of Pensylvania, US
- **Sylvain Merlet**, INRIA, Sophia-Antipolis, FR
- **Erick Ziegler**, Université de Liège, BE
- **Kimberly Chan**, Stanford University, CA, US

Boundless collaboration is in the heart of Dipy_. We encourage everyone from anywhere in the world to join the team. You can start sharing your code `here`__. If you want to contribute but you don't know in area to focus, please send us an e-mail. We will be more than happy to help.

__ `dipy github`_

.. include:: links_names.inc
